@@ -103,7 +103,7 @@ static GCallback data_from_jukebox_to_hd (GtkButton *button,
 
 
 /* Move the files off the Harddisk and into the Jukebox */
-static GCallback data_from_hd_to_jukebox()
+static GCallback data_from_hd_to_jukebox(GtkButton *button/*UNUSED*/, gpointer user_data/*UNUSED*/)
 {
   hd2jb_data_thread_arg_t *hd2jb_data_thread_args;
   GList *metalist = get_all_metadata_from_selection(HDDATA_LIST);
@@ -229,7 +229,7 @@ static GCallback hdmenu_delete_response(gpointer data)
 }
 
 /* Handles descending into a directory */
-static void go_down()
+static void go_down(void)
 {
   gchar *path;
   metadata_t *meta;
@@ -257,7 +257,7 @@ static void go_down()
   destroy_metadata_t(meta);
 }
 
-static void go_down_jukebox()
+static void go_down_jukebox(void)
 {
   metadata_t *meta;
 
@@ -508,6 +508,11 @@ static GtkWidget *create_listview(GtkListStore *liststore)
   
   dirtextrenderer = gtk_cell_renderer_text_new ();
   textrenderer = gtk_cell_renderer_text_new ();
+  g_object_set(G_OBJECT(textrenderer),
+	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
+	       "weight", NULL,
+	       "underline", FALSE,
+	       NULL);
 
   view = gtk_tree_view_column_new_with_attributes (_("Filename"),
 						   dirtextrenderer,
