@@ -29,6 +29,9 @@ Boston, MA 02111-1307, USA.
 #include "util.h"
 #include "id3read.h"
 #include "prefs.h"
+#ifdef HAVE_TAGLIB
+#include "tagfile.h"
+#endif
 
 static listtype_t target;
 static GtkWidget *edit_dialog;
@@ -228,11 +231,16 @@ static void edit_ok_click ( GtkButton *button,
       while (gtk_events_pending())
 	gtk_main_iteration();
       if (target == HD_LIST) {
-	/*
-	 * g_print("Updating: %s\n", newmeta->path);
-	 * dump_metadata_t(newmeta);
-	 */
-	set_tag_for_mp3file(newmeta, TRUE);
+         /*
+          * g_print("Updating: %s\n", newmeta->path);
+          * dump_metadata_t(newmeta);
+          */	 
+         if(!strcmp(newmeta->codec, "MP3"))
+            set_tag_for_mp3file(newmeta, TRUE);
+#ifdef HAVE_TAGLIB
+         else if(!strcmp(newmeta->codec, "OGG") || !strcmp(newmeta->codec, "FLAC"))
+            set_tag_for_file(newmeta, TRUE);
+#endif
       } else {
 	/*
 	 * g_print("Updating: %s\n", newmeta->path);
@@ -665,10 +673,15 @@ static GList *filter_for_editing(GList *metadatas, guint listtype)
     metadata_t *meta = (metadata_t  *) tmp->data;
     if (meta->size == 0) {
       /* Throw this away */
-      destroy_metadata_t(meta);
-    } else if ( (listtype == HD_LIST) &&
-		strcmp(meta->codec, "MP3") ) {
-      // If on the host side, we can only edit MP3 ID3v1/v2
+       destroy_metadata_t(meta);
+    } else if ( (listtype == HD_LIST)
+		&& strcmp(meta->codec, "MP3")
+#ifdef HAVE_TAGLIB
+                && strcmp(meta->codec, "OGG")
+		&& strcmp(meta->codec, "FLAC")
+#endif
+		) {
+      // If on the host side, we can only edit MP3 ID3v1/v2 plug OGG/FLAC
       // metadata, so filter out anything else.
       destroy_metadata_t(meta);
     } else {
