@@ -1,6 +1,6 @@
 /* filesystem.c
    Interface to the posix (well...) file system
-   Copyright (C) 2001-2006 Linus Walleij
+   Copyright (C) 2001-2007 Linus Walleij
 
 This file is part of the GNOMAD package.
 
@@ -27,6 +27,9 @@ Boston, MA 02111-1307, USA.
 #include "wmaread.h"
 #include "wavfile.h"
 #include "xfer.h"
+#ifdef HAVE_TAGLIB
+#include "tagfile.h"
+#endif
 #if !GTK_CHECK_VERSION(2,4,0)
 #include <libgnomeui/libgnomeui.h>
 #endif
@@ -322,7 +325,7 @@ static GList *get_directory_listing(gchar* base_path, gboolean anyfile)
 	}
 #endif
       } else if (is_file) {
-	char tmp_codec[4];
+	char tmp_codec[5];
 	char *tmp;
 
 	if (!anyfile) {
@@ -332,23 +335,24 @@ static GList *get_directory_listing(gchar* base_path, gboolean anyfile)
 	  /* Must have sane filename */
 	  if (strlen(dir_entry->d_name) < 4)
 	    continue;
-	  strcpy(tmp_codec, dir_entry->d_name+strlen(dir_entry->d_name)-3);
+
+	  strcpy(tmp_codec, dir_entry->d_name+strlen(dir_entry->d_name)-4);
 	  tmp = g_utf8_strdown(tmp_codec, -1);
 	  /* Only display valid files */
-	  if (g_ascii_strcasecmp(tmp,"mp3") &&
-	      g_ascii_strcasecmp(tmp,"wav") &&
-	      g_ascii_strcasecmp(tmp,"wma")
+          if (g_ascii_strcasecmp(tmp+1,"mp3") &&
+              g_ascii_strcasecmp(tmp+1,"wav") &&
+              g_ascii_strcasecmp(tmp+1,"wma")
 #ifdef HAVE_LIBMTP
 	      // Additional music codecs supported by libmtp
 	      // TODO: base this on the list of filetypes actually
 	      // supported by a particular device, if one is connected.
 	      &&
-	      g_ascii_strcasecmp(tmp,"ogg") &&
+	      g_ascii_strcasecmp(tmp+1,"ogg") &&
 	      g_ascii_strcasecmp(tmp,"flac") &&
-	      g_ascii_strcasecmp(tmp,"mp2") &&
-	      g_ascii_strcasecmp(tmp,"m4a") &&
-	      g_ascii_strcasecmp(tmp,"aac") &&
-	      g_ascii_strcasecmp(tmp,"mp4")
+	      g_ascii_strcasecmp(tmp+1,"mp2") &&
+	      g_ascii_strcasecmp(tmp+1,"m4a") &&
+	      g_ascii_strcasecmp(tmp+1,"aac") &&
+	      g_ascii_strcasecmp(tmp+1,"mp4")
 #endif
 	      ) {
 	    g_free(tmp);
@@ -495,12 +499,18 @@ static GList *get_metadata_for_dirlist(GList *inlist,
 	  get_tag_for_wmafile(meta);
 	}
 #ifdef HAVE_LIBMTP
-	// Implement getting track metadata for the other libmtp
-	// supported filetypes here...
 	if (!strcmp(meta->codec,"OGG")) {
+#ifdef HAVE_TAGLIB
+           get_tag_for_file(meta);
+#endif
 	}
 	if (!strcmp(meta->codec,"FLAC")) {
+#ifdef HAVE_TAGLIB
+           get_tag_for_file(meta);
+#endif
 	}
+	// Implement getting track metadata for the other libmtp
+	// supported filetypes here...
 	if (!strcmp(meta->codec,"MP2")) {
 	}
 	if (!strcmp(meta->codec,"M4A")) {
