@@ -264,7 +264,8 @@ static void about_box(gpointer data)
 			  strcmp(translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			  NULL);
 #endif
-  gtk_widget_show(about);
+  gtk_dialog_run(GTK_DIALOG(about));
+  gtk_widget_destroy(about);
 }
 
 /*
