@@ -24,24 +24,24 @@ Boston, MA 02111-1307, USA.
 #include <gtk/gtk.h>
 
 /* Exported functions */
-void write_prefs_file();
-gboolean get_prefs_id3override();
-gboolean get_prefs_id3remove();
-gboolean get_prefs_useid3();
-gboolean get_prefs_useid3_unicode();
-gboolean get_prefs_display_dotdirs();
-gboolean get_prefs_ask_playlist();
-gboolean get_prefs_recurse_dir();
+void write_prefs_file(void);
+gboolean get_prefs_id3override(void);
+gboolean get_prefs_id3remove(void);
+gboolean get_prefs_useid3(void);
+gboolean get_prefs_useid3_unicode(void);
+gboolean get_prefs_display_dotdirs(void);
+gboolean get_prefs_ask_playlist(void);
+gboolean get_prefs_recurse_dir(void);
 #ifndef G_OS_WIN32
-gboolean get_prefs_force_8859();
+gboolean get_prefs_force_8859(void);
 #endif
-gboolean get_prefs_detect_metadata();
-gboolean get_prefs_extended_metadata();
-gboolean get_prefs_use_origname();
-gboolean get_prefs_autoscan();
-gboolean get_prefs_set_time();
-gboolean get_prefs_turbo_mode();
-gchar *get_prefs_filenameformat();
+gboolean get_prefs_detect_metadata(void);
+gboolean get_prefs_extended_metadata(void);
+gboolean get_prefs_use_origname(void);
+gboolean get_prefs_autoscan(void);
+gboolean get_prefs_set_time(void);
+gboolean get_prefs_turbo_mode(void);
+gchar *get_prefs_filenameformat(void);
 void create_prefs_widgets(GtkWidget *box);
 
 #endif
